@@ -25,6 +25,9 @@
       ftmp <- .maketmp()
       ret <- write_envi(obj,paste0(ftmp,"."))
       pr <- ifelse(ret %in% c(1L,2L,3L,11L,12L,13L),2L,3L)
+      fpath <- dirname(fname)
+      if (!dir.exists(fpath))
+         dir.create(fpath,recursive=TRUE)
       proj_lib <- Sys.getenv("PROJ_LIB")
       Sys.setenv(PROJ_LIB=file.path(dirname(dirname(Sys.which("gdal_translate")))
                                    ,"share/proj"))
