@@ -126,6 +126,8 @@
 'envi_list' <- function(pattern=".+",path=".",all.files=FALSE,full.names=recursive
                        ,recursive=FALSE,ignore.case=TRUE,exact=FALSE)
 {
+   if (length(pattern)>1)
+      return(do.call(c,lapply(pattern,envi_list))) ## RECURSIVE
    '.noESRI' <- function(elist) {
       fpath <- ifelse(full.names | length(grep("/",elist)),elist,file.path(path,elist))
       a <- elist[sapply(fpath,function(f) readLines(paste0(f,".hdr"),1)=="ENVI")]
@@ -219,3 +221,21 @@
   #    return(list2[ind])
    character()
 }
+'ursa_exists' <- function(fname) {
+   list1 <- envi_list(fname)
+   if (length(list1)>1) {
+      print(list1)
+      warning("Multiple datasests")
+      return(FALSE)
+   }
+   if (length(list1)==1)
+      return(TRUE)
+   list1 <- dir(path=dirname(fname),pattern=basename(fname),full.names=TRUE)
+   if (length(list1)) {
+      ind <- grep("\\.(tif|tiff|hfa|bin)$",basename(list1))
+      if (length(ind)==1)
+         return(TRUE)
+      return(FALSE)
+   }
+   return(FALSE)
+}
